'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');

function createUseMediaFactory(useEffectHook) {
  return (query, {
    initialValue
  } = {}) => {
    const [match, setMatch] = React.useState(() => initialValue === undefined && typeof window !== 'undefined' ? window.matchMedia(query).matches : Boolean(initialValue));
    useEffectHook(() => {
      if (!window || !window.matchMedia) {
        return;
      }
      const matchMedia = window.matchMedia(query);
      const updateMatch = event => setMatch(event.matches);
      setMatch(matchMedia.matches);
      matchMedia.addListener(updateMatch);
      return () => {
        matchMedia.removeListener(updateMatch);
      };
    }, [query]);
    return match;
  };
}
const useMedia = createUseMediaFactory(React.useEffect);
const useMediaLayout = createUseMediaFactory(React.useLayoutEffect);

exports.useMedia = useMedia;
exports.useMediaLayout = useMediaLayout;
